
[![CI](https://img.shields.io/github/actions/workflow/status/bnzk/django-formfieldstash/ci.yml?style=flat-square&logo=github "CI")](https://github.com/bnzk/django-formfieldstash/actions/workflows/ci.yml)
[![Version](https://img.shields.io/pypi/v/django-formfieldstash.svg?style=flat-square "Version")](https://pypi.python.org/pypi/django-formfieldstash/)
[![Licence](https://img.shields.io/github/license/bnzk/django-formfieldstash.svg?style=flat-square "Licence")](https://pypi.python.org/pypi/django-formfieldstash/)
[![PyPI Downloads](https://img.shields.io/pypi/dm/django-formfieldstash?style=flat-square "PyPi Downloads")](https://pypistats.org/packages/django-formfieldstash)

show/hide modelform fields, depending on current value of a dropdown in the form. without page reload.
this is a pure javascript solution, using a modeladminmixin and/or Widget(attrs=stash_attr_helper(stash_config) approach.

Development and Docs on `<https://github.com/bnzk/django-formfieldstash/>`_

![CI](https://raw.githubusercontent.com/bnzk/django-formfieldstash/main/docs/formfieldstash.gif "Demo GIF")
 